@@ -14,7 +14,7 @@ from pyderman import drivers
 from pyderman.drivers import all_drivers, chrome, edge, firefox, opera, phantomjs
 from pyderman.util import downloader
 
-__version__ = "3.0.0"
+__version__ = "3.2.0"
 
 _versions = sorted(["32", "64"], key=lambda _v: not platform.machine().endswith(_v))
 _os_opts = [("win", "win", ".exe"), ("darwin", "mac", ""), ("linux", "linux", "")]
@@ -49,7 +49,7 @@ def install(
     """
     Downloads the given browser driver, and returns the path it was saved to.
 
-    :param browser: The Driver to download. Pass as `pyderman.chrome/firefox`. Default Chrome.
+    :param browser: The Driver to download. Pass as `pyderman.chrome/firefox/etc.`. Default Chrome.
     :param file_directory: The directory to save the driver.
     :param verbose: If printouts are okay during downloading.
     :param chmod: If True, attempt to make the downloaded driver executable.
